@@ -1,8 +1,6 @@
 import argparse
-import log
 import logging
 
-# logger = log.logging_set_up()
 logger = logging.getLogger('Formatter')
 
 
