@@ -1,7 +1,9 @@
 import logging
 
-from .fileFormatter import FileFormatter
-from .cmdParser import CmdParser
+from fileFormatter import FileFormatter
+from cmdParser import CmdParser
+import log
+
 
 logger = logging.getLogger('Formatter')
 
